@@ -1,4 +1,5 @@
-/*
+/**
+ * \file
  * This header is only installed for use by the debugger:
  * the structures and the API declared here are not supported.
  */
@@ -6,14 +7,17 @@
 #ifndef __MONO_DEBUG_H__
 #define __MONO_DEBUG_H__
 
-#include <glib.h>
+#include <mono/utils/mono-publib.h>
 #include <mono/metadata/image.h>
 #include <mono/metadata/appdomain.h>
 
+MONO_BEGIN_DECLS
+
 typedef struct _MonoSymbolTable			MonoSymbolTable;
 typedef struct _MonoDebugDataTable		MonoDebugDataTable;
 
 typedef struct _MonoSymbolFile			MonoSymbolFile;
+typedef struct _MonoPPDBFile			MonoPPDBFile;
 
 typedef struct _MonoDebugHandle			MonoDebugHandle;
 
@@ -26,6 +30,8 @@ typedef struct _MonoDebugMethodAddressList	MonoDebugMethodAddressList;
 typedef struct _MonoDebugClassEntry		MonoDebugClassEntry;
 
 typedef struct _MonoDebugMethodInfo		MonoDebugMethodInfo;
+typedef struct _MonoDebugLocalsInfo		MonoDebugLocalsInfo;
+typedef struct _MonoDebugMethodAsyncInfo	MonoDebugMethodAsyncInfo;
 typedef struct _MonoDebugSourceLocation		MonoDebugSourceLocation;
 
 typedef struct _MonoDebugList			MonoDebugList;
@@ -33,6 +39,7 @@ typedef struct _MonoDebugList			MonoDebugList;
 typedef enum {
 	MONO_DEBUG_FORMAT_NONE,
 	MONO_DEBUG_FORMAT_MONO,
+	/* Deprecated, the mdb debugger is not longer supported. */
 	MONO_DEBUG_FORMAT_DEBUGGER
 } MonoDebugFormat;
 
@@ -43,13 +50,13 @@ typedef enum {
 */
 struct _MonoDebugList {
 	MonoDebugList *next;
-	gconstpointer data;
+	const void* data;
 };
 
 struct _MonoSymbolTable {
-	guint64 magic;
-	guint32 version;
-	guint32 total_size;
+	uint64_t magic;
+	uint32_t version;
+	uint32_t total_size;
 
 	/*
 	 * Corlib and metadata info.
@@ -65,40 +72,46 @@ struct _MonoSymbolTable {
 };
 
 struct _MonoDebugHandle {
-	guint32 index;
+	uint32_t index;
 	char *image_file;
 	MonoImage *image;
 	MonoDebugDataTable *type_table;
 	MonoSymbolFile *symfile;
+	MonoPPDBFile *ppdb;
 };
 
 struct _MonoDebugMethodJitInfo {
-	const guint8 *code_start;
-	guint32 code_size;
-	guint32 prologue_end;
-	guint32 epilogue_begin;
-	const guint8 *wrapper_addr;
-	guint32 num_line_numbers;
+	const mono_byte *code_start;
+	uint32_t code_size;
+	uint32_t prologue_end;
+	uint32_t epilogue_begin;
+	const mono_byte *wrapper_addr;
+	uint32_t num_line_numbers;
 	MonoDebugLineNumberEntry *line_numbers;
-	guint32 num_params;
+	uint32_t has_var_info;
+	uint32_t num_params;
 	MonoDebugVarInfo *this_var;
 	MonoDebugVarInfo *params;
-	guint32 num_locals;
+	uint32_t num_locals;
 	MonoDebugVarInfo *locals;
+	MonoDebugVarInfo *gsharedvt_info_var;
+	MonoDebugVarInfo *gsharedvt_locals_var;
 };
 
 struct _MonoDebugMethodAddressList {
-	guint32 size;
-	guint32 count;
-	guint8 data [MONO_ZERO_LEN_ARRAY];
+	uint32_t size;
+	uint32_t count;
+	mono_byte data [MONO_ZERO_LEN_ARRAY];
 };
 
 struct _MonoDebugSourceLocation {
-	gchar *source_file;
-	guint32 row, column;
-	guint32 il_offset;
+	char *source_file;
+	uint32_t row, column;
+	uint32_t il_offset;
 };
 
+MONO_API mono_bool mono_debug_enabled (void);
+
 /*
  * These bits of the MonoDebugLocalInfo's "index" field are flags specifying
  * where the variable is actually stored.
@@ -119,76 +132,88 @@ struct _MonoDebugSourceLocation {
 /* The variable is dead. */
 #define MONO_DEBUG_VAR_ADDRESS_MODE_DEAD		0x30000000
 
+/* Same as REGOFFSET, but do an indirection */
+#define MONO_DEBUG_VAR_ADDRESS_MODE_REGOFFSET_INDIR		0x40000000
+
+/* gsharedvt local */
+#define MONO_DEBUG_VAR_ADDRESS_MODE_GSHAREDVT_LOCAL		0x50000000
+
+/* variable is a vt address */
+#define MONO_DEBUG_VAR_ADDRESS_MODE_VTADDR		0x60000000
+
 struct _MonoDebugVarInfo {
-	guint32 index;
-	guint32 offset;
-	guint32 size;
-	guint32 begin_scope;
-	guint32 end_scope;
+	uint32_t index;
+	uint32_t offset;
+	uint32_t size;
+	uint32_t begin_scope;
+	uint32_t end_scope;
 	MonoType *type;
 };
 
 #define MONO_DEBUGGER_MAJOR_VERSION			81
-#define MONO_DEBUGGER_MINOR_VERSION			5
+#define MONO_DEBUGGER_MINOR_VERSION			6
 #define MONO_DEBUGGER_MAGIC				0x7aff65af4253d427ULL
 
-extern MonoSymbolTable *mono_symbol_table;
-extern MonoDebugFormat mono_debug_format;
-extern GHashTable *mono_debug_handles;
-extern gint32 mono_debug_debugger_version;
-extern gint32 _mono_debug_using_mono_debugger;
+MONO_API void mono_debug_init (MonoDebugFormat format);
+MONO_API void mono_debug_open_image_from_memory (MonoImage *image, const mono_byte *raw_contents, int size);
+MONO_API void mono_debug_cleanup (void);
 
-void mono_debug_list_add (MonoDebugList **list, gconstpointer data);
-void mono_debug_list_remove (MonoDebugList **list, gconstpointer data);
+MONO_API void mono_debug_close_image (MonoImage *image);
 
-void mono_debug_init (MonoDebugFormat format);
-void mono_debug_open_image_from_memory (MonoImage *image, const guint8 *raw_contents, int size);
-void mono_debug_cleanup (void);
+MONO_API void mono_debug_domain_unload (MonoDomain *domain);
+MONO_API void mono_debug_domain_create (MonoDomain *domain);
 
-void mono_debug_close_image (MonoImage *image);
-
-void mono_debug_domain_unload (MonoDomain *domain);
-void mono_debug_domain_create (MonoDomain *domain);
-
-gboolean mono_debug_using_mono_debugger (void);
-
-MonoDebugMethodAddress *
+MONO_API MonoDebugMethodAddress *
 mono_debug_add_method (MonoMethod *method, MonoDebugMethodJitInfo *jit, MonoDomain *domain);
 
-MonoDebugMethodInfo *
+MONO_API void
+mono_debug_remove_method (MonoMethod *method, MonoDomain *domain);
+
+MONO_API MonoDebugMethodInfo *
 mono_debug_lookup_method (MonoMethod *method);
 
-MonoDebugMethodAddressList *
+MONO_API MonoDebugMethodAddressList *
 mono_debug_lookup_method_addresses (MonoMethod *method);
 
-MonoDebugMethodJitInfo*
+MONO_API MonoDebugMethodJitInfo*
 mono_debug_find_method (MonoMethod *method, MonoDomain *domain);
 
-void
+MONO_API MonoDebugHandle *
+mono_debug_get_handle (MonoImage *image);
+
+MONO_API void
 mono_debug_free_method_jit_info (MonoDebugMethodJitInfo *jit);
 
 
-void
-mono_debug_add_delegate_trampoline (gpointer code, int size);
+MONO_API void
+mono_debug_add_delegate_trampoline (void* code, int size);
 
-int
-mono_debug_lookup_locals (MonoMethod *method, char ***names, int **indexes);
+MONO_API MonoDebugLocalsInfo*
+mono_debug_lookup_locals (MonoMethod *method);
+
+MonoDebugMethodAsyncInfo*
+mono_debug_lookup_method_async_debug_info (MonoMethod *method);
+
+// The intent here is really MONO_LLVM_INTERNAL but that is not necessarily available.
+MONO_API
+MonoDebugSourceLocation *
+mono_debug_method_lookup_location (MonoDebugMethodInfo *minfo, int il_offset);
 
 /*
  * Line number support.
  */
 
-MonoDebugSourceLocation *
-mono_debug_lookup_source_location (MonoMethod *method, guint32 address, MonoDomain *domain);
+MONO_API MonoDebugSourceLocation *
+mono_debug_lookup_source_location (MonoMethod *method, uint32_t address, MonoDomain *domain);
 
-gint32
-mono_debug_il_offset_from_address (MonoMethod *method, MonoDomain *domain, guint32 native_offset);
+MONO_API int32_t
+mono_debug_il_offset_from_address (MonoMethod *method, MonoDomain *domain, uint32_t native_offset);
 
-void
+MONO_API void
 mono_debug_free_source_location (MonoDebugSourceLocation *location);
 
-gchar *
-mono_debug_print_stack_frame (MonoMethod *method, guint32 native_offset, MonoDomain *domain);
+MONO_API char *
+mono_debug_print_stack_frame (MonoMethod *method, uint32_t native_offset, MonoDomain *domain);
 
 /*
  * Mono Debugger support functions
@@ -196,10 +221,12 @@ mono_debug_print_stack_frame (MonoMethod *method, guint32 native_offset, MonoDom
  * These methods are used by the JIT while running inside the Mono Debugger.
  */
 
-int             mono_debugger_method_has_breakpoint       (MonoMethod *method);
-int             mono_debugger_insert_breakpoint           (const gchar *method_name, gboolean include_namespace);
+MONO_API int             mono_debugger_method_has_breakpoint       (MonoMethod *method);
+MONO_API int             mono_debugger_insert_breakpoint           (const char *method_name, mono_bool include_namespace);
 
-void mono_set_is_debugger_attached (gboolean attached);
-gboolean mono_is_debugger_attached (void);
+MONO_API void mono_set_is_debugger_attached (mono_bool attached);
+MONO_API mono_bool mono_is_debugger_attached (void);
+
+MONO_END_DECLS
 
 #endif /* __MONO_DEBUG_H__ */
