@@ -12,7 +12,7 @@
 #define G_SEARCHPATH_SEPARATOR   ':'
 #define G_DIR_SEPARATOR          '/'
 #define G_DIR_SEPARATOR_S        "/"
-#define G_BREAKPOINT()           G_STMT_START { __asm__ ("int $03"); } G_STMT_END
+#define G_BREAKPOINT()           G_STMT_START { raise (SIGTRAP); } G_STMT_END
 #define G_OS_UNIX
 
 #if 0 == 1
@@ -26,7 +26,7 @@
 typedef size_t gsize;
 typedef ptrdiff_t gssize;
 
-#define G_GSIZE_FORMAT   "%lu"
+#define G_GSIZE_FORMAT   "lu"
 
 #if defined (HOST_WATCHOS)
 #undef G_BREAKPOINT
